@@ -94,6 +94,21 @@ class ProductActionResponse(_InteractiveTaskResponse):
     pass
 
 
+class ScheduledExecutionResponse(_Response):
+
+    def __init__(self, status, output=None):
+        super().__init__(status)
+        self.output = output
+
+    @classmethod
+    def done(cls):
+        return cls(ResultType.SUCCESS)
+
+    @classmethod
+    def fail(cls, output=None):
+        return cls(ResultType.FAIL, output=output)
+
+
 class Extension:
     def __init__(self, client, logger, config):
         self.client = client
@@ -101,7 +116,7 @@ class Extension:
         self.config = config
 
     @classmethod
-    def get_descriptor(cls):
+    def get_descriptor(cls):  # pragma: no cover
         return json.load(
             pkg_resources.resource_stream(
                 cls.__module__,
@@ -153,3 +168,18 @@ class Extension:
 
     def process_product_custom_event(self, request):  # pragma: no cover
         raise NotImplementedError()
+
+    def process_new_listing_request(self, request):  # pragma: no cover
+        raise NotImplementedError()
+
+    def process_remove_listing_request(self, request):  # pragma: no cover
+        raise NotImplementedError()
+
+    def process_tier_account_update_request(self, request):  # pragma: no cover
+        raise NotImplementedError()
+
+    def process_usage_file(self, request):  # pragma: no cover
+        raise NotImplementedError()
+
+    def process_usage_chunk_file(self, request):  # pragma: no cover
+        raise NotImplementedError()
